@@ -1,24 +1,30 @@
 #!/bin/bash
 
-# Get an updated config.sub and config.guess
-cp $BUILD_PREFIX/share/gnuconfig/config.* .
+mkdir -p build && cd build
 
-export CFLAGS="-O2 -Wl,-S ${CFLAGS}"
-export CXXFLAGS="-O2 -Wl,-S ${CXXFLAGS}"
-
-if [ ! -f configure ]; then
-    ./autogen.sh
+if [[ "$CONDA_BUILD_CROSS_COMPILATION" != "1" ]]; then
+    EXE_SQLITE3=${PREFIX}/bin/sqlite3
+else
+    EXE_SQLITE3=${BUILD_PREFIX}/bin/sqlite3
 fi
 
-./configure --prefix=${PREFIX} --host=${HOST} --disable-static
+cmake ${CMAKE_ARGS} \
+      -D CMAKE_BUILD_TYPE=Release \
+      -D BUILD_SHARED_LIBS=ON \
+      -D CMAKE_INSTALL_PREFIX=${PREFIX} \
+      -D CMAKE_INSTALL_LIBDIR=lib \
+      -D EXE_SQLITE3=${EXE_SQLITE3} \
+      ${SRC_DIR}
+
+make -j${CPU_COUNT} ${VERBOSE_CM}
 
-make -j${CPU_COUNT}
 # skip tests on linux32 due to rounding error causing issues
 if [[ ! ${HOST} =~ .*linux.* ]] || [[ ! ${ARCH} == 32 ]]; then
 if [[ "${CONDA_BUILD_CROSS_COMPILATION}" != "1" ]]; then
-    make check -j${CPU_COUNT}
+    ctest --output-on-failure
 fi
 fi
+
 make install -j${CPU_COUNT}
 
 ACTIVATE_DIR=${PREFIX}/etc/conda/activate.d
